@@ -49,12 +49,13 @@ config defaults
 
 '''
 
+try:
+    import flask
+    import yamlpage
+except ImportError:
+    # for installation
+    pass
 
-import flask
-import yamlpage
-
-
-__version__ = '0.0.2'
 
 
 class FlaskYamlPage(yamlpage.YamlPage):
